@@ -266,6 +266,8 @@ int background_functions(
   double rho_ncdm,p_ncdm,pseudo_p_ncdm;
   /* index for n_ncdm species */
   int n_ncdm;
+  /* fluid's time-dependent equation of state parameter */
+  double w_fld, dw_over_da, integral_fld;
   /* scale factor */
   double a;
   /* scalar field quantities */
@@ -390,13 +392,22 @@ int background_functions(
     p_tot -= pvecback[pba->index_bg_rho_lambda];
   }
 
-  /* fluid with w=w0+wa(1-a/a0) and constant cs2 */
+  /* fluid with w(a) and constant cs2 */
   if (pba->has_fld == _TRUE_) {
-    pvecback[pba->index_bg_rho_fld] = pba->Omega0_fld * pow(pba->H0,2)
-      / pow(a_rel,3.*(1.+pba->w0_fld+pba->wa_fld))
-      * exp(3.*pba->wa_fld*(a_rel-1.));
+
+    /* get rho_fld from vector of integrated variables */
+    pvecback[pba->index_bg_rho_fld] = pvecback_B[pba->index_bi_rho_fld];
+
+    /* get w_fld from dedicated function */
+    class_call(background_w_fld(pba,a,&w_fld,&dw_over_da,&integral_fld), pba->error_message, pba->error_message);
+    pvecback[pba->index_bg_w_fld] = w_fld;
+
+    // Obsolete: at the beginning, we had here the analytic integral solution corresponding to the case w=w0+w1(1-a/a0):
+    // pvecback[pba->index_bg_rho_fld] = pba->Omega0_fld * pow(pba->H0,2) / pow(a_rel,3.*(1.+pba->w0_fld+pba->wa_fld)) * exp(3.*pba->wa_fld*(a_rel-1.));
+    // But now everthing is integrated numerically for a given w_fld(a) defined in the function background_w_fld.
+
     rho_tot += pvecback[pba->index_bg_rho_fld];
-    p_tot += (pba->w0_fld+pba->wa_fld*(1.-a_rel)) * pvecback[pba->index_bg_rho_fld];
+    p_tot += w_fld * pvecback[pba->index_bg_rho_fld];
   }
 
   /* relativistic neutrinos (and all relativistic relics) */
@@ -441,6 +452,101 @@ int background_functions(
 
 }
 
+/**
+ * Single place where the fluid equation of state is
+ * defined. Parameters of the function are passed through the
+ * background structure. Generalisation to arbitrary functions should
+ * be simple.
+ *
+ * @param pba            Input: pointer to background structure
+ * @param a              Input: current value of scale factor
+ * @param w_fld          Output: equation of state parameter w_fld(a)
+ * @param dw_over_da_fld Output: function dw_fld/da
+ * @param integral_fld   Output: function \f$ \int_{a}^{a_0} da 3(1+w_{fld})/a \f$
+ * @return the error status
+ */
+
+int background_w_fld(
+                     struct background * pba,
+                     double a,
+                     double * w_fld,
+                     double * dw_over_da_fld,
+                     double * integral_fld) {
+
+  double Omega_ede = 0.;
+  double dOmega_ede_over_da = 0.;
+  double d2Omega_ede_over_da2 = 0.;
+  double a_eq, Omega_r, Omega_m;
+
+  /** - first, define the function w(a) */
+  switch (pba->fluid_equation_of_state) {
+  case CLP:
+    *w_fld = pba->w0_fld + pba->wa_fld * (1. - a / pba->a_today);
+    break;
+  case EDE:
+    // Omega_ede(a) taken from eq. (10) in 1706.00730
+    Omega_ede = (pba->Omega0_fld - pba->Omega_EDE*(1.-pow(a,-3.*pba->w0_fld)))
+      /(pba->Omega0_fld+(1.-pba->Omega0_fld)*pow(a,3.*pba->w0_fld))
+      + pba->Omega_EDE*(1.-pow(a,-3.*pba->w0_fld));
+
+    // d Omega_ede / d a taken analytically from the above
+    dOmega_ede_over_da = - pba->Omega_EDE* 3.*pba->w0_fld*pow(a,-3.*pba->w0_fld-1.)/(pba->Omega0_fld+(1.-pba->Omega0_fld)*pow(a,3.*pba->w0_fld))
+      - (pba->Omega0_fld - pba->Omega_EDE*(1.-pow(a,-3.*pba->w0_fld)))*(1.-pba->Omega0_fld)*3.*pba->w0_fld*pow(a,3.*pba->w0_fld-1.)/pow(pba->Omega0_fld+(1.-pba->Omega0_fld)*pow(a,3.*pba->w0_fld),2)
+      + pba->Omega_EDE*3.*pba->w0_fld*pow(a,-3.*pba->w0_fld-1.);
+
+    // find a_equality (needed because EDE tracks first radiation, then matter)
+    Omega_r = pba->Omega0_g * (1. + 3.046 * 7./8.*pow(4./11.,4./3.)); // assumes LambdaCDM + eventually massive neutrinos so light that they are relativistic at equality; needs to be generalised later on.
+    Omega_m = pba->Omega0_b;
+    if (pba->has_cdm == _TRUE_) Omega_m += pba->Omega0_cdm;
+    if (pba->has_dcdm == _TRUE_)
+        class_stop(pba->error_message,"Early Dark Energy not compatible with decaying Dark Matter because we omitted to code the calculation of a_eq in that case, but it would not be difficult to add it if necessary, should be a matter of 5 minutes");
+    a_eq = Omega_r/Omega_m; // assumes a flat universe with a=1 today
+    class_stop(pba->error_message,"a_eq = %e, z_eq =%e\n",a_eq,1./a_eq-1.);
+
+    // w_ede(a) taken from eq. (11) in 1706.00730
+    *w_fld = - dOmega_ede_over_da*a/Omega_ede/3./(1.-Omega_ede)+a_eq/3./(a+a_eq);
+    break;
+  }
+
+
+  /** - then, give the corresponding analytic derivative dw/da (used
+        by perturbation equations; we could compute it numerically,
+        but with a loss of precision; as long as there is a simple
+        analytic expression of the derivative of the previous
+        function, let's use it! */
+  switch (pba->fluid_equation_of_state) {
+  case CLP:
+    *dw_over_da_fld = - pba->wa_fld / pba->a_today;
+    break;
+  case EDE:
+    d2Omega_ede_over_da2 = 0.;
+    *dw_over_da_fld = - d2Omega_ede_over_da2*a/3./(1.-Omega_ede)/Omega_ede
+      - dOmega_ede_over_da/3./(1.-Omega_ede)/Omega_ede
+      + dOmega_ede_over_da*dOmega_ede_over_da*a/3./(1.-Omega_ede)/(1.-Omega_ede)/Omega_ede
+      + a_eq/3./(a+a_eq)/(a+a_eq);
+    break;
+  }
+
+  /** - finally, give the analytic solution of the following integral:
+        \f$ \int_{a}^{a0} da 3(1+w_{fld})/a \f$. This is used in only
+        one place, in the initial conditions for the background, and
+        with a=a_ini. If your w(a) does not lead to a simple analytic
+        solution of this integral, no worry: instead of writing
+        something here, the best would then be to leave it equal to
+        zero, and then in background_initial_conditions() you should
+        implement a numerical calculation of this integral only for
+        a=a_ini, using for instance Romberg integration. It should be
+        fast, simple, and accurate enough. */
+  *integral_fld = 3.*((1.+pba->w0_fld+pba->wa_fld)*log(pba->a_today/a) + pba->wa_fld*(a/pba->a_today-1.));
+
+  /** note: of course you can generalise these formulas to anything,
+      defining new parameters pba->w..._fld. Just remember that so
+      far, HyRec explicitely assumes that w(a)= w0 + wa (1-a/a0); but
+      Recfast does not assume anything */
+
+  return _SUCCESS_;
+}
+
 /**
  * Initialize the background structure, and in particular the
  * background interpolation table.
@@ -461,6 +567,7 @@ int background_init(
   int n_ncdm;
   double rho_ncdm_rel,rho_nu_rel;
   double Neff;
+  double w_fld, dw_over_da, integral_fld;
   int filenum=0;
 
   /** - in verbose mode, provide some information */
@@ -534,30 +641,36 @@ int background_init(
   /** - control that cosmological parameter values make sense */
 
   /* H0 in Mpc^{-1} */
-  class_test((pba->H0 < _H0_SMALL_)||(pba->H0 > _H0_BIG_),
+  /* Many users asked for this test to be supressed. It is commented out. */
+  /*class_test((pba->H0 < _H0_SMALL_)||(pba->H0 > _H0_BIG_),
              pba->error_message,
-             "H0=%g out of bounds (%g<H0<%g) \n",pba->H0,_H0_SMALL_,_H0_BIG_);
+             "H0=%g out of bounds (%g<H0<%g) \n",pba->H0,_H0_SMALL_,_H0_BIG_);*/
 
   class_test(fabs(pba->h * 1.e5 / _c_  / pba->H0 -1.)>ppr->smallest_allowed_variation,
              pba->error_message,
              "inconsistency between Hubble and reduced Hubble parameters: you have H0=%f/Mpc=%fkm/s/Mpc, but h=%f",pba->H0,pba->H0/1.e5* _c_,pba->h);
 
   /* T_cmb in K */
-  class_test((pba->T_cmb < _TCMB_SMALL_)||(pba->T_cmb > _TCMB_BIG_),
+  /* Many users asked for this test to be supressed. It is commented out. */
+  /*class_test((pba->T_cmb < _TCMB_SMALL_)||(pba->T_cmb > _TCMB_BIG_),
              pba->error_message,
-             "T_cmb=%g out of bounds (%g<T_cmb<%g)",pba->T_cmb,_TCMB_SMALL_,_TCMB_BIG_);
+             "T_cmb=%g out of bounds (%g<T_cmb<%g)",pba->T_cmb,_TCMB_SMALL_,_TCMB_BIG_);*/
 
-  /* H0 in Mpc^{-1} */
-  class_test((pba->Omega0_k < _OMEGAK_SMALL_)||(pba->Omega0_k > _OMEGAK_BIG_),
+  /* Omega_k */
+  /* Many users asked for this test to be supressed. It is commented out. */
+  /*class_test((pba->Omega0_k < _OMEGAK_SMALL_)||(pba->Omega0_k > _OMEGAK_BIG_),
              pba->error_message,
-             "Omegak = %g out of bounds (%g<Omegak<%g) \n",pba->Omega0_k,_OMEGAK_SMALL_,_OMEGAK_BIG_);
+             "Omegak = %g out of bounds (%g<Omegak<%g) \n",pba->Omega0_k,_OMEGAK_SMALL_,_OMEGAK_BIG_);*/
 
   /* fluid equation of state */
   if (pba->has_fld == _TRUE_) {
-    class_test(pba->w0_fld+pba->wa_fld>=1./3.,
+
+    class_call(background_w_fld(pba,0.,&w_fld,&dw_over_da,&integral_fld), pba->error_message, pba->error_message);
+
+    class_test(w_fld >= 1./3.,
                pba->error_message,
-               "Your choice for w0_fld+wa_fld=%g is suspicious, there would not be radiation domination at early times\n",
-               pba->w0_fld+pba->wa_fld);
+               "Your choice for w(a--->0)=%g is suspicious, since it is bigger than -1/3 there cannot be radiation domination at early times\n",
+               w_fld);
   }
 
   /* in verbose mode, inform the user about the value of the ncdm
@@ -587,6 +700,11 @@ int background_init(
              pba->error_message,
              pba->error_message);
 
+  /** - this function finds and stores a few derived parameters at radiation-matter equality */
+  class_call(background_find_equality(ppr,pba),
+             pba->error_message,
+             pba->error_message);
+
   return _SUCCESS_;
 
 }
@@ -615,6 +733,24 @@ int background_free(
   return err;
 }
 
+/**
+ * Free only the memory space NOT allocated through input_read_parameters()
+ *
+ * @param pba Input: pointer to background structure (to be freed)
+ * @return the error status
+ */
+
+int background_free_noinput(
+                    struct background *pba
+                    ) {
+  free(pba->tau_table);
+  free(pba->z_table);
+  free(pba->d2tau_dz2_table);
+  free(pba->background_table);
+  free(pba->d2background_dtau2_table);
+
+  return _SUCCESS_;
+}
 /**
  * Free pointers inside background structure which were
  * allocated in input_read_parameters()
@@ -636,7 +772,9 @@ int background_free_input(
       free(pba->w_ncdm_bg[k]);
       free(pba->dlnf0_dlnq_ncdm[k]);
     }
-
+    free(pba->ncdm_quadrature_strategy);
+    free(pba->ncdm_input_q_size);
+    free(pba->ncdm_qmax);
     free(pba->q_ncdm);
     free(pba->w_ncdm);
     free(pba->q_ncdm_bg);
@@ -775,6 +913,7 @@ int background_indices(
 
   /* - index for fluid */
   class_define_index(pba->index_bg_rho_fld,pba->has_fld,index_bg,1);
+  class_define_index(pba->index_bg_w_fld,pba->has_fld,index_bg,1);
 
   /* - index for ultra-relativistic neutrinos/species */
   class_define_index(pba->index_bg_rho_ur,pba->has_ur,index_bg,1);
@@ -840,6 +979,9 @@ int background_indices(
   /* -> energy density in DR */
   class_define_index(pba->index_bi_rho_dr,pba->has_dr,index_bi,1);
 
+  /* -> energy density in fluid */
+  class_define_index(pba->index_bi_rho_fld,pba->has_fld,index_bi,1);
+
   /* -> scalar field and its derivative wrt conformal time (Zuma) */
   class_define_index(pba->index_bi_phi_scf,pba->has_scf,index_bi,1);
   class_define_index(pba->index_bi_phi_prime_scf,pba->has_scf,index_bi,1);
@@ -853,8 +995,9 @@ int background_indices(
   /* -> sound horizon */
   class_define_index(pba->index_bi_rs,_TRUE_,index_bi,1);
 
-  /* -> integral for growth factor */
-  class_define_index(pba->index_bi_growth,_TRUE_,index_bi,1);
+  /* -> Second order equation for growth factor */
+  class_define_index(pba->index_bi_D,_TRUE_,index_bi,1);
+  class_define_index(pba->index_bi_D_prime,_TRUE_,index_bi,1);
 
   /* -> index for conformal time in vector of variables to integrate */
   class_define_index(pba->index_bi_tau,_TRUE_,index_bi,1);
@@ -955,7 +1098,7 @@ int background_ncdm_distribution(
     /**
        Next enter your analytic expression(s) for the p.s.d.'s. If
        you need different p.s.d.'s for different species, put each
-       p.s.d inside a condition, like for instance: if (n_ncdm==2) 
+       p.s.d inside a condition, like for instance: if (n_ncdm==2)
        {*f0=...}.  Remember that n_ncdm = 0 refers to the first
        species.
     */
@@ -1117,59 +1260,93 @@ int background_ncdm_init(
     }
 
     /* Handle perturbation qsampling: */
-    class_alloc(pba->q_ncdm[k],_QUADRATURE_MAX_*sizeof(double),pba->error_message);
-    class_alloc(pba->w_ncdm[k],_QUADRATURE_MAX_*sizeof(double),pba->error_message);
+    if (pba->ncdm_quadrature_strategy[k]==qm_auto){
+      /** Automatic q-sampling for this species */
+      class_alloc(pba->q_ncdm[k],_QUADRATURE_MAX_*sizeof(double),pba->error_message);
+      class_alloc(pba->w_ncdm[k],_QUADRATURE_MAX_*sizeof(double),pba->error_message);
 
-    class_call(get_qsampling(pba->q_ncdm[k],
-                             pba->w_ncdm[k],
-                             &(pba->q_size_ncdm[k]),
-                             _QUADRATURE_MAX_,
-                             ppr->tol_ncdm,
-                             pbadist.q,
-                             pbadist.tablesize,
-                             background_ncdm_test_function,
-                             background_ncdm_distribution,
-                             &pbadist,
-                             pba->error_message),
-               pba->error_message,
-               pba->error_message);
-    pba->q_ncdm[k]=realloc(pba->q_ncdm[k],pba->q_size_ncdm[k]*sizeof(double));
-    pba->w_ncdm[k]=realloc(pba->w_ncdm[k],pba->q_size_ncdm[k]*sizeof(double));
+      class_call(get_qsampling(pba->q_ncdm[k],
+			       pba->w_ncdm[k],
+			       &(pba->q_size_ncdm[k]),
+			       _QUADRATURE_MAX_,
+			       ppr->tol_ncdm,
+			       pbadist.q,
+			       pbadist.tablesize,
+			       background_ncdm_test_function,
+			       background_ncdm_distribution,
+			       &pbadist,
+			       pba->error_message),
+		 pba->error_message,
+		 pba->error_message);
+      pba->q_ncdm[k]=realloc(pba->q_ncdm[k],pba->q_size_ncdm[k]*sizeof(double));
+      pba->w_ncdm[k]=realloc(pba->w_ncdm[k],pba->q_size_ncdm[k]*sizeof(double));
 
 
-    if (pba->background_verbose > 0)
-      printf("ncdm species i=%d sampled with %d points for purpose of perturbation integration\n",
-             k+1,
-             pba->q_size_ncdm[k]);
+      if (pba->background_verbose > 0)
+	printf("ncdm species i=%d sampled with %d points for purpose of perturbation integration\n",
+	       k+1,
+	       pba->q_size_ncdm[k]);
 
-    /* Handle background q_sampling: */
-    class_alloc(pba->q_ncdm_bg[k],_QUADRATURE_MAX_BG_*sizeof(double),pba->error_message);
-    class_alloc(pba->w_ncdm_bg[k],_QUADRATURE_MAX_BG_*sizeof(double),pba->error_message);
+      /* Handle background q_sampling: */
+      class_alloc(pba->q_ncdm_bg[k],_QUADRATURE_MAX_BG_*sizeof(double),pba->error_message);
+      class_alloc(pba->w_ncdm_bg[k],_QUADRATURE_MAX_BG_*sizeof(double),pba->error_message);
 
-    class_call(get_qsampling(pba->q_ncdm_bg[k],
-                             pba->w_ncdm_bg[k],
-                             &(pba->q_size_ncdm_bg[k]),
-                             _QUADRATURE_MAX_BG_,
-                             ppr->tol_ncdm_bg,
-                             pbadist.q,
-                             pbadist.tablesize,
-                             background_ncdm_test_function,
-                             background_ncdm_distribution,
-                             &pbadist,
-                             pba->error_message),
-               pba->error_message,
-               pba->error_message);
+      class_call(get_qsampling(pba->q_ncdm_bg[k],
+			       pba->w_ncdm_bg[k],
+			       &(pba->q_size_ncdm_bg[k]),
+			       _QUADRATURE_MAX_BG_,
+			       ppr->tol_ncdm_bg,
+			       pbadist.q,
+			       pbadist.tablesize,
+			       background_ncdm_test_function,
+			       background_ncdm_distribution,
+			       &pbadist,
+			       pba->error_message),
+		 pba->error_message,
+		 pba->error_message);
 
 
-    pba->q_ncdm_bg[k]=realloc(pba->q_ncdm_bg[k],pba->q_size_ncdm_bg[k]*sizeof(double));
-    pba->w_ncdm_bg[k]=realloc(pba->w_ncdm_bg[k],pba->q_size_ncdm_bg[k]*sizeof(double));
+      pba->q_ncdm_bg[k]=realloc(pba->q_ncdm_bg[k],pba->q_size_ncdm_bg[k]*sizeof(double));
+      pba->w_ncdm_bg[k]=realloc(pba->w_ncdm_bg[k],pba->q_size_ncdm_bg[k]*sizeof(double));
 
+      /** - in verbose mode, inform user of number of sampled momenta
+	  for background quantities */
+      if (pba->background_verbose > 0)
+	printf("ncdm species i=%d sampled with %d points for purpose of background integration\n",
+	       k+1,
+	       pba->q_size_ncdm_bg[k]);
+    }
+    else{
+      /** Manual q-sampling for this species. Same sampling used for both perturbation and background sampling, since this will usually be a high precision setting anyway */
+      pba->q_size_ncdm_bg[k] = pba->ncdm_input_q_size[k];
+      pba->q_size_ncdm[k] = pba->ncdm_input_q_size[k];
+      class_alloc(pba->q_ncdm_bg[k],pba->q_size_ncdm_bg[k]*sizeof(double),pba->error_message);
+      class_alloc(pba->w_ncdm_bg[k],pba->q_size_ncdm_bg[k]*sizeof(double),pba->error_message);
+      class_alloc(pba->q_ncdm[k],pba->q_size_ncdm[k]*sizeof(double),pba->error_message);
+      class_alloc(pba->w_ncdm[k],pba->q_size_ncdm[k]*sizeof(double),pba->error_message);
+      class_call(get_qsampling_manual(pba->q_ncdm[k],
+				      pba->w_ncdm[k],
+				      pba->q_size_ncdm[k],
+				      pba->ncdm_qmax[k],
+				      pba->ncdm_quadrature_strategy[k],
+				      pbadist.q,
+				      pbadist.tablesize,
+				      background_ncdm_distribution,
+				      &pbadist,
+				      pba->error_message),
+		 pba->error_message,
+		 pba->error_message);
+      for (index_q=0; index_q<pba->q_size_ncdm[k]; index_q++) {
+	pba->q_ncdm_bg[k][index_q] = pba->q_ncdm[k][index_q];
+	pba->w_ncdm_bg[k][index_q] = pba->w_ncdm[k][index_q];
+      }
     /** - in verbose mode, inform user of number of sampled momenta
         for background quantities */
-    if (pba->background_verbose > 0)
-      printf("ncdm species i=%d sampled with %d points for purpose of background integration\n",
-             k+1,
-             pba->q_size_ncdm_bg[k]);
+      if (pba->background_verbose > 0)
+	printf("ncdm species i=%d sampled with %d points for purpose of background andperturbation integration using the manual method\n",
+	       k+1,
+	       pba->q_size_ncdm[k]);
+    }
 
     class_alloc(pba->dlnf0_dlnq_ncdm[k],
                 pba->q_size_ncdm[k]*sizeof(double),
@@ -1271,7 +1448,7 @@ int background_ncdm_momenta(
   double q2;
   double factor2;
   /** Summary: */
-  
+
   /** - rescale normalization at given redshift */
   factor2 = factor*pow(1+z,4);
 
@@ -1300,7 +1477,7 @@ int background_ncdm_momenta(
   }
 
   /** - adjust normalization */
-  if (n!=NULL) *n *= factor2*(1.+z);
+  if (n!=NULL) *n *= factor2/(1.+z);
   if (rho!=NULL) *rho *= factor2;
   if (p!=NULL) *p *= factor2;
   if (drho_dM!=NULL) *drho_dM *= factor2;
@@ -1593,11 +1770,10 @@ int background_solve(
 
     /* -> compute growth functions (valid in dust universe) */
 
-    /* D = H \int [da/(aH)^3] = H \int [dtau/(aH^2)] = H * growth */
-    pvecback[pba->index_bg_D] = pvecback[pba->index_bg_H]*pData[i*pba->bi_size+pba->index_bi_growth];
-
-    /* f = [dlnD]/[dln a] = 1/(aH) [dlnD]/[dtau] = H'/(aH^2) + 1/(a^2 H^3 growth) */
-    pvecback[pba->index_bg_f] = pvecback[pba->index_bg_H_prime]/pvecback[pba->index_bg_a]/pvecback[pba->index_bg_H]/pvecback[pba->index_bg_H] + 1./(pvecback[pba->index_bg_a]*pvecback[pba->index_bg_a]*pvecback[pba->index_bg_H]*pvecback[pba->index_bg_H]*pvecback[pba->index_bg_H]*pData[i*pba->bi_size+pba->index_bi_growth]);
+    /* Normalise D(z=0)=1 and construct f = D_prime/(aHD) */
+    pvecback[pba->index_bg_D] = pData[i*pba->bi_size+pba->index_bi_D]/pData[(pba->bt_size-1)*pba->bi_size+pba->index_bi_D];
+    pvecback[pba->index_bg_f] = pData[i*pba->bi_size+pba->index_bi_D_prime]/
+      (pData[i*pba->bi_size+pba->index_bi_D]*pvecback[pba->index_bg_a]*pvecback[pba->index_bg_H]);
 
     /* -> write in the table */
     memcopy_result = memcpy(pba->background_table + i*pba->bg_size,pvecback,pba->bg_size*sizeof(double));
@@ -1634,7 +1810,7 @@ int background_solve(
              pba->error_message,
              pba->error_message);
 
-  /** - compute remaining "related parameters" 
+  /** - compute remaining "related parameters"
    *     - so-called "effective neutrino number", computed at earliest
       time in interpolation table. This should be seen as a
       definition: Neff is the equivalent number of
@@ -1711,6 +1887,8 @@ int background_initial_conditions(
   double f,Omega_rad, rho_rad;
   int counter,is_early_enough,n_ncdm;
   double scf_lambda;
+  double rho_fld_today;
+  double w_fld,dw_over_da_fld,integral_fld;
 
   /** - fix initial value of \f$ a \f$ */
   a = ppr->a_ini_over_a_today_default * pba->a_today;
@@ -1778,9 +1956,9 @@ int background_initial_conditions(
   if (pba->has_dr == _TRUE_){
     if (pba->has_dcdm == _TRUE_){
       /**  - f is the critical density fraction of DR. The exact solution is:
-       * 
+       *
        * `f = -Omega_rad+pow(pow(Omega_rad,3./2.)+0.5*pow(a/pba->a_today,6)*pvecback_integration[pba->index_bi_rho_dcdm]*pba->Gamma_dcdm/pow(pba->H0,3),2./3.);`
-       * 
+       *
        * but it is not numerically stable for very small f which is always the case.
        * Instead we use the Taylor expansion of this equation, which is equivalent to
        * ignoring f(a) in the Hubble rate.
@@ -1794,12 +1972,31 @@ int background_initial_conditions(
     }
   }
 
+  if (pba->has_fld == _TRUE_){
+
+    /* rho_fld today */
+    rho_fld_today = pba->Omega0_fld * pow(pba->H0,2);
+
+    /* integrate rho_fld(a) from a_ini to a_0, to get rho_fld(a_ini) given rho_fld(a0) */
+    class_call(background_w_fld(pba,a,&w_fld,&dw_over_da_fld,&integral_fld), pba->error_message, pba->error_message);
+
+    /* Note: for complicated w_fld(a) functions with no simple
+    analytic integral, this is the place were you should compute
+    numerically the simple 1d integral [int_{a_ini}^{a_0} 3
+    [(1+w_fld)/a] da] (e.g. with the Romberg method?) instead of
+    calling background_w_fld */
+
+    /* rho_fld at initial time */
+    pvecback_integration[pba->index_bi_rho_fld] = rho_fld_today * exp(integral_fld);
+
+  }
+
   /** - Fix initial value of \f$ \phi, \phi' \f$
    * set directly in the radiation attractor => fixes the units in terms of rho_ur
-   * 
-   * TODO: 
-   * - There seems to be some small oscillation when it starts. 
-   * - Check equations and signs. Sign of phi_prime? 
+   *
+   * TODO:
+   * - There seems to be some small oscillation when it starts.
+   * - Check equations and signs. Sign of phi_prime?
    * - is rho_ur all there is early on?
    */
   if(pba->has_scf == _TRUE_){
@@ -1860,18 +2057,94 @@ int background_initial_conditions(
   /** - compute initial sound horizon, assuming \f$ c_s=1/\sqrt{3} \f$ initially */
   pvecback_integration[pba->index_bi_rs] = pvecback_integration[pba->index_bi_tau]/sqrt(3.);
 
-  /** - compute initial value of the integral over \f$ d\tau /(aH^2) \f$,
-      assumed to be proportional to \f$ a^4 \f$ during RD, but with arbitrary
-      normalization */
-  pvecback_integration[pba->index_bi_growth] = 1./(4.*a*a*pvecback[pba->index_bg_H]*pvecback[pba->index_bg_H]*pvecback[pba->index_bg_H]);
+  /** - set initial value of D and D' in RD. D will be renormalised later, but D' must be correct. */
+  pvecback_integration[pba->index_bi_D] = a;
+  pvecback_integration[pba->index_bi_D_prime] = 2*pvecback_integration[pba->index_bi_D]*pvecback[pba->index_bg_H];
 
   return _SUCCESS_;
 
 }
 
+/**
+ * Find the time of radiation/matter equality and store characteristic
+ * quantitites at that time in the background structure..
+ *
+ * @param ppr                  Input: pointer to precision structure
+ * @param pba                  Input/Output: pointer to background structure
+  * @return the error status
+ */
+
+int background_find_equality(
+                             struct precision *ppr,
+                             struct background *pba) {
+
+  double Omega_m_over_Omega_r=0.;
+  int index_tau_minus = 0;
+  int index_tau_plus = pba->bt_size-1;
+  int index_tau_mid = 0;
+  double tau_minus,tau_plus,tau_mid=0.;
+  double * pvecback;
+
+  /* first bracket the right tau value between two consecutive indices in the table */
+
+  while ((index_tau_plus - index_tau_minus) > 1) {
+
+    index_tau_mid = (int)(0.5*(index_tau_plus+index_tau_minus));
+
+    Omega_m_over_Omega_r = pba->background_table[index_tau_mid*pba->bg_size+pba->index_bg_Omega_m]
+      /pba->background_table[index_tau_mid*pba->bg_size+pba->index_bg_Omega_r];
+
+    if (Omega_m_over_Omega_r > 1)
+      index_tau_plus = index_tau_mid;
+    else
+      index_tau_minus = index_tau_mid;
+
+  }
+
+  /* then get a better estimate within this range */
+
+  tau_minus = pba->tau_table[index_tau_minus];
+  tau_plus =  pba->tau_table[index_tau_plus];
+
+  class_alloc(pvecback,pba->bg_size*sizeof(double),pba->error_message);
+
+  while ((tau_plus - tau_minus) > ppr->tol_tau_eq) {
+
+    tau_mid = 0.5*(tau_plus+tau_minus);
+
+    class_call(background_at_tau(pba,tau_mid,pba->long_info,pba->inter_closeby,&index_tau_minus,pvecback),
+               pba->error_message,
+               pba->error_message);
+
+    Omega_m_over_Omega_r = pvecback[pba->index_bg_Omega_m]/pvecback[pba->index_bg_Omega_r];
+
+    if (Omega_m_over_Omega_r > 1)
+      tau_plus = tau_mid;
+    else
+      tau_minus = tau_mid;
+
+  }
+
+  pba->a_eq = pvecback[pba->index_bg_a];
+  pba->H_eq = pvecback[pba->index_bg_H];
+  pba->z_eq = pba->a_today/pba->a_eq -1.;
+  pba->tau_eq = tau_mid;
+
+  if (pba->background_verbose > 0) {
+    printf(" -> radiation/matter equality at z = %f\n",pba->z_eq);
+    printf("    corresponding to conformal time = %f Mpc\n",pba->tau_eq);
+  }
+
+  free(pvecback);
+
+  return _SUCCESS_;
+
+}
+
+
 /**
  * Subroutine for formatting background output
- * 
+ *
  */
 
 int background_output_titles(struct background * pba,
@@ -1904,6 +2177,7 @@ int background_output_titles(struct background * pba,
   }
   class_store_columntitle(titles,"(.)rho_lambda",pba->has_lambda);
   class_store_columntitle(titles,"(.)rho_fld",pba->has_fld);
+  class_store_columntitle(titles,"(.)w_fld",pba->has_fld);
   class_store_columntitle(titles,"(.)rho_ur",pba->has_ur);
   class_store_columntitle(titles,"(.)rho_crit",_TRUE_);
   class_store_columntitle(titles,"(.)rho_dcdm",pba->has_dcdm);
@@ -1955,6 +2229,7 @@ int background_output_data(
     }
     class_store_double(dataptr,pvecback[pba->index_bg_rho_lambda],pba->has_lambda,storeidx);
     class_store_double(dataptr,pvecback[pba->index_bg_rho_fld],pba->has_fld,storeidx);
+    class_store_double(dataptr,pvecback[pba->index_bg_w_fld],pba->has_fld,storeidx);
     class_store_double(dataptr,pvecback[pba->index_bg_rho_ur],pba->has_ur,storeidx);
     class_store_double(dataptr,pvecback[pba->index_bg_rho_crit],_TRUE_,storeidx);
     class_store_double(dataptr,pvecback[pba->index_bg_rho_dcdm],pba->has_dcdm,storeidx);
@@ -2016,7 +2291,7 @@ int background_derivs(
 
   struct background_parameters_and_workspace * pbpaw;
   struct background * pba;
-  double * pvecback;
+  double * pvecback, a, H, rho_M;
 
   pbpaw = parameters_and_workspace;
   pba =  pbpaw->pba;
@@ -2027,6 +2302,10 @@ int background_derivs(
              pba->error_message,
              error_message);
 
+  /** - Short hand notation */
+  a = y[pba->index_bi_a];
+  H = pvecback[pba->index_bg_H];
+
   /** - calculate \f$ a'=a^2 H \f$ */
   dy[pba->index_bi_a] = y[pba->index_bi_a] * y[pba->index_bi_a] * pvecback[pba->index_bg_H];
 
@@ -2040,8 +2319,12 @@ int background_derivs(
   /** - calculate \f$ rs' = c_s \f$*/
   dy[pba->index_bi_rs] = 1./sqrt(3.*(1.+3.*pvecback[pba->index_bg_rho_b]/4./pvecback[pba->index_bg_rho_g]))*sqrt(1.-pba->K*y[pba->index_bi_rs]*y[pba->index_bi_rs]); // TBC: curvature correction
 
-  /** - calculate growth' \f$ = 1/(aH^2) \f$ */
-  dy[pba->index_bi_growth] = 1./(y[pba->index_bi_a] * pvecback[pba->index_bg_H] * pvecback[pba->index_bg_H]);
+  /** - solve second order growth equation  \f$ [D''(\tau)=-aHD'(\tau)+3/2 a^2 \rho_M D(\tau) \f$ */
+  rho_M = pvecback[pba->index_bg_rho_b];
+  if (pba->has_cdm)
+    rho_M += pvecback[pba->index_bg_rho_cdm];
+  dy[pba->index_bi_D] = y[pba->index_bi_D_prime];
+  dy[pba->index_bi_D_prime] = -a*H*y[pba->index_bi_D_prime] + 1.5*a*a*rho_M*y[pba->index_bi_D];
 
   if (pba->has_dcdm == _TRUE_){
     /** - compute dcdm density \f$ \rho' = -3aH \rho - a \Gamma \rho \f$*/
@@ -2055,6 +2338,11 @@ int background_derivs(
       y[pba->index_bi_a]*pba->Gamma_dcdm*y[pba->index_bi_rho_dcdm];
   }
 
+  if (pba->has_fld == _TRUE_) {
+    /** - Compute fld density \f$ \rho' = -3aH (1+w_{fld}(a)) \rho \f$ */
+    dy[pba->index_bi_rho_fld] = -3.*y[pba->index_bi_a]*pvecback[pba->index_bg_H]*(1.+pvecback[pba->index_bg_w_fld])*y[pba->index_bi_rho_fld];
+  }
+
   if (pba->has_scf == _TRUE_){
     /** - Scalar field equation: \f$ \phi'' + 2 a H \phi' + a^2 dV = 0 \f$  (note H is wrt cosmic time) */
     dy[pba->index_bi_phi_scf] = y[pba->index_bi_phi_prime_scf];
@@ -2072,19 +2360,19 @@ int background_derivs(
  * Scalar field potential and its derivatives with respect to the field _scf
  * For Albrecht & Skordis model: 9908085
  * - \f$ V = V_{p_{scf}}*V_{e_{scf}} \f$
- * - \f$ V_e =  \exp(-\lambda \phi) \f$ (exponential) 
- * - \f$ V_p = (\phi - B)^\alpha + A \f$ (polynomial bump) 
- * 
- * TODO: 
+ * - \f$ V_e =  \exp(-\lambda \phi) \f$ (exponential)
+ * - \f$ V_p = (\phi - B)^\alpha + A \f$ (polynomial bump)
+ *
+ * TODO:
  * - Add some functionality to include different models/potentials (tuning would be difficult, though)
  * - Generalize to Kessence/Horndeski/PPF and/or couplings
  * - A default module to numerically compute the derivatives when no analytic functions are given should be added.
  * - Numerical derivatives may further serve as a consistency check.
- * 
+ *
  */
 
-/** 
- * 
+/**
+ *
  * The units of phi, tau in the derivatives and the potential V are the following:
  * - phi is given in units of the reduced Planck mass \f$ m_{pl} = (8 \pi G)^{(-1/2)}\f$
  * - tau in the derivative is given in units of Mpc.
@@ -2129,12 +2417,12 @@ double ddV_e_scf(struct background *pba,
 
 
 /** parameters and functions for the polynomial coefficient
- * \f$ V_p = (\phi - B)^\alpha + A \f$(polynomial bump) 
- * 
+ * \f$ V_p = (\phi - B)^\alpha + A \f$(polynomial bump)
+ *
  * double scf_alpha = 2;
- * 
+ *
  * double scf_B = 34.8;
- * 
+ *
  * double scf_A = 0.01; (values for their Figure 2)
  */
 
