@@ -39,7 +39,7 @@
 
 #include "lss/nc_cluster_mass_benson_xray.h"
 #include "math/integral.h"
-#include "math/memory_pool.h"
+#include "math/ncm_memory_pool.h"
 #include "math/ncm_cfg.h"
 
 #ifndef NUMCOSMO_GIR_SCAN
