@@ -5,6 +5,7 @@
  *  Copyright  2012  Sandro Dias Pinto Vitenti
  *  <sandro@isoftware.com.br>
  ****************************************************************************/
+
 /*
  * numcosmo
  * Copyright (C) Sandro Dias Pinto Vitenti 2012 <sandro@isoftware.com.br>
@@ -57,6 +58,7 @@ struct _NcmFftlogClass
   /*< private >*/
   GObjectClass parent_class;
   const gchar *name;
+  
   void (*get_Ym) (NcmFftlog *fftlog, gpointer Ym_0);
 };
 
@@ -84,6 +86,7 @@ struct _NcmFftlog
   NcmVector *lnr_vec;
   GPtrArray *Gr_vec;
   GPtrArray *Gr_s;
+  
 #ifdef NUMCOSMO_HAVE_FFTW3
   fftw_complex *Fk;
   fftw_complex *Cm;
@@ -92,16 +95,17 @@ struct _NcmFftlog
   GPtrArray *Ym;
   fftw_plan p_Fk2Cm;
   fftw_plan p_CmYm2Gr;
+  
 #endif /* NUMCOSMO_HAVE_FFTW3 */
 };
 
 GType ncm_fftlog_get_type (void) G_GNUC_CONST;
 
 NcmFftlog *ncm_fftlog_ref (NcmFftlog *fftlog);
+
 void ncm_fftlog_free (NcmFftlog *fftlog);
 void ncm_fftlog_clear (NcmFftlog **fftlog);
 
-void ncm_fftlog_set_name (NcmFftlog *fftlog, const gchar *name);
 const gchar *ncm_fftlog_peek_name (NcmFftlog *fftlog);
 
 void ncm_fftlog_set_nderivs (NcmFftlog *fftlog, guint nderivs);
@@ -186,19 +190,19 @@ ncm_fftlog_get_length (NcmFftlog *fftlog)
   return fftlog->Lk;
 }
 
-NCM_INLINE gdouble 
+NCM_INLINE gdouble
 ncm_fftlog_get_full_length (NcmFftlog *fftlog)
 {
   return fftlog->Lk + 2.0 * fftlog->Lk_N * fftlog->pad;
 }
 
-NCM_INLINE gint 
+NCM_INLINE gint
 ncm_fftlog_get_mode_index (NcmFftlog *fftlog, gint i)
 {
   return (i > fftlog->Nf_2) ? i - fftlog->Nf : i;
 }
 
-NCM_INLINE gint 
+NCM_INLINE gint
 ncm_fftlog_get_array_index (NcmFftlog *fftlog, gint phys_i)
 {
   return (phys_i < 0) ? phys_i + fftlog->Nf : phys_i;
@@ -215,3 +219,4 @@ G_END_DECLS
 #endif /* __GTK_DOC_IGNORE__ */
 #endif /* NUMCOSMO_HAVE_INLINE */
 #endif /* _NCM_FFTLOG_INLINE_H_ */
+
