@@ -13,12 +13,12 @@
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * numcosmo is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -27,18 +27,20 @@
  * SECTION:ncm_powspec
  * @title: NcmPowspec
  * @short_description: Abstrac class for power spectrum implementation.
+ * @stability: Stable
+ * @include: numcosmo/math/ncm_powspec.h
  *
  * This module comprises the set of functions to compute a power spectrum and
  * derived quantities.
- * 
- * Given a field $\delta(\vec{x})$ at position $\vec{x}$, the power spectrum is 
- * defined as the Fourier transform of the two-point correlation point, i.e., 
+ *
+ * Given a field $\delta(\vec{x})$ at position $\vec{x}$, the power spectrum is
+ * defined as the Fourier transform of the two-point correlation point, i.e.,
  * $$\xi(\vec{x} - \vec{x}^\prime) = \int \frac{d^3 k}{(2 \pi)^3} e^{i \vec{k}.(\vec{x} - \vec{x}^\prime)} P(k),$$
- * where $\langle \delta(\vec{k} - \vec{k}^\prime)\rangle = (2\pi)^3 \delta_D(\vec{k} - \vec{k}^\prime) P(k)$ 
- * and $\delta_D$ is the Dirac's delta function. 
- * The standard output is the dimensional power spectrum, not the dimensionless one $\Delta(k)^2$, 
+ * where $\langle \delta(\vec{k} - \vec{k}^\prime)\rangle = (2\pi)^3 \delta_D(\vec{k} - \vec{k}^\prime) P(k)$
+ * and $\delta_D$ is the Dirac's delta function.
+ * The standard output is the dimensional power spectrum, not the dimensionless one $\Delta(k)^2$,
  * $$P(k) \equiv \frac{2 \pi^2 \Delta(k)^2}{k^3}.$$
- * 
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -75,7 +77,7 @@ ncm_powspec_init (NcmPowspec *powspec)
   powspec->zf   = 0.0;
   powspec->kmin = 0.0;
   powspec->kmax = 0.0;
-
+  
   powspec->ctrl = ncm_model_ctrl_new (NULL);
 }
 
@@ -83,9 +85,9 @@ static void
 _ncm_powspec_dispose (GObject *object)
 {
   NcmPowspec *powspec = NCM_POWSPEC (object);
-
+  
   ncm_model_ctrl_clear (&powspec->ctrl);
-
+  
   /* Chain up : end */
   G_OBJECT_CLASS (ncm_powspec_parent_class)->dispose (object);
 }
@@ -93,7 +95,6 @@ _ncm_powspec_dispose (GObject *object)
 static void
 _ncm_powspec_finalize (GObject *object)
 {
-
   /* Chain up : end */
   G_OBJECT_CLASS (ncm_powspec_parent_class)->finalize (object);
 }
@@ -102,8 +103,9 @@ static void
 _ncm_powspec_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
   NcmPowspec *powspec = NCM_POWSPEC (object);
+  
   g_return_if_fail (NCM_IS_POWSPEC (object));
-
+  
   switch (prop_id)
   {
     case PROP_ZI:
@@ -128,8 +130,9 @@ static void
 _ncm_powspec_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 {
   NcmPowspec *powspec = NCM_POWSPEC (object);
+  
   g_return_if_fail (NCM_IS_POWSPEC (object));
-
+  
   switch (prop_id)
   {
     case PROP_ZI:
@@ -150,21 +153,38 @@ _ncm_powspec_get_property (GObject *object, guint prop_id, GValue *value, GParam
   }
 }
 
-static void _ncm_powspec_prepare (NcmPowspec *powspec, NcmModel *model) { g_error ("_ncm_powspec_prepare: no default implementation, all children must implement it."); } 
-static gdouble _ncm_powspec_eval (NcmPowspec *powspec, NcmModel *model, const gdouble z, const gdouble k) { g_error ("_ncm_powspec_eval: no default implementation, all children must implement it."); return 0.0; }
+static void
+_ncm_powspec_prepare (NcmPowspec *powspec, NcmModel *model)
+{
+  g_error ("_ncm_powspec_prepare: no default implementation, all children must implement it.");
+}
+
+static gdouble
+_ncm_powspec_eval (NcmPowspec *powspec, NcmModel *model, const gdouble z, const gdouble k)
+{
+  g_error ("_ncm_powspec_eval: no default implementation, all children must implement it.");
+  
+  return 0.0;
+}
+
 static void _ncm_powspec_eval_vec (NcmPowspec *powspec, NcmModel *model, const gdouble z, NcmVector *k, NcmVector *Pk);
 
 static void
 ncm_powspec_class_init (NcmPowspecClass *klass)
 {
-  GObjectClass* object_class = G_OBJECT_CLASS (klass);
-
+  GObjectClass *object_class = G_OBJECT_CLASS (klass);
+  
   object_class->set_property = &_ncm_powspec_set_property;
   object_class->get_property = &_ncm_powspec_get_property;
-
-  object_class->dispose      = &_ncm_powspec_dispose;
-  object_class->finalize     = &_ncm_powspec_finalize;
-
+  
+  object_class->dispose  = &_ncm_powspec_dispose;
+  object_class->finalize = &_ncm_powspec_finalize;
+  
+  /**
+   * NcmPowspec:zi:
+   *
+   * The initial time (redshift) to compute $P(k,z)$.
+   */
   g_object_class_install_property (object_class,
                                    PROP_ZI,
                                    g_param_spec_double ("zi",
@@ -172,23 +192,38 @@ ncm_powspec_class_init (NcmPowspecClass *klass)
                                                         "Initial time",
                                                         0.0, G_MAXDOUBLE, 0.0,
                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB));
-
+  
+  /**
+   * NcmPowspec:zf:
+   *
+   * The final time (redshift) to compute $P(k,z)$.
+   */
   g_object_class_install_property (object_class,
-                                   PROP_ZF, 
+                                   PROP_ZF,
                                    g_param_spec_double ("zf",
                                                         NULL,
                                                         "Final time",
                                                         0.0, G_MAXDOUBLE, 1.0,
                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB));
-
+  
+  /**
+   * NcmPowspec:kmin:
+   *
+   * The minimum mode (wavenumber) value to compute $P(k,z)$.
+   */
   g_object_class_install_property (object_class,
                                    PROP_KMIN,
                                    g_param_spec_double ("kmin",
                                                         NULL,
-                                                       "Minimum mode value",
+                                                        "Minimum mode value",
                                                         0.0, G_MAXDOUBLE, 1.0e-5,
-                                                       G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB));
-
+                                                        G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB));
+  
+  /**
+   * NcmPowspec:kmax:
+   *
+   * The maximum mode (wavenumber) value to compute $P(k,z)$.
+   */
   g_object_class_install_property (object_class,
                                    PROP_KMAX,
                                    g_param_spec_double ("kmax",
@@ -196,23 +231,26 @@ ncm_powspec_class_init (NcmPowspecClass *klass)
                                                         "Maximum mode value",
                                                         0.0, G_MAXDOUBLE, 1.0,
                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB));
-
+  
   klass->prepare  = &_ncm_powspec_prepare;
   klass->eval     = &_ncm_powspec_eval;
   klass->eval_vec = &_ncm_powspec_eval_vec;
 }
 
-static void 
-_ncm_powspec_eval_vec (NcmPowspec *powspec, NcmModel *model, const gdouble z, NcmVector *k, NcmVector *Pk) 
-{ 
+static void
+_ncm_powspec_eval_vec (NcmPowspec *powspec, NcmModel *model, const gdouble z, NcmVector *k, NcmVector *Pk)
+{
   const guint len = ncm_vector_len (k);
   guint i;
+  
   for (i = 0; i < len; i++)
   {
     const gdouble ki  = ncm_vector_get (k, i);
     const gdouble Pki = ncm_powspec_eval (powspec, model, z, ki);
+    
     ncm_vector_set (Pk, i, Pki);
   }
+  
   return;
 }
 
@@ -220,7 +258,7 @@ _ncm_powspec_eval_vec (NcmPowspec *powspec, NcmModel *model, const gdouble z, Nc
  * ncm_powspec_ref:
  * @powspec: a #NcmPowspec
  *
- * Increases the reference count of @powspec by one.
+ * Increases the reference count of @powspec by one atomically.
  *
  * Returns: (transfer full): @powspec.
  */
@@ -234,10 +272,12 @@ ncm_powspec_ref (NcmPowspec *powspec)
  * ncm_powspec_free:
  * @powspec: a #NcmPowspec
  *
- * Decreases the reference count of @powspec by one.
+ * Atomically decrements the reference count of @powspec by one.
+ * If the reference count drops to 0,
+ * all memory allocated by @powspec is released.
  *
  */
-void 
+void
 ncm_powspec_free (NcmPowspec *powspec)
 {
   g_object_unref (powspec);
@@ -247,11 +287,13 @@ ncm_powspec_free (NcmPowspec *powspec)
  * ncm_powspec_clear:
  * @powspec: a #NcmPowspec
  *
- * If @powspec is different from NULL, decreases the reference count of 
- * @powspec by one and sets @powspec to NULL.
+ * If @powspec is different from NULL,
+ * atomically decrements the reference count of @powspec by one.
+ * If the reference count drops to 0,
+ * all memory allocated by @powspec is released and @powspec is set to NULL.
  *
  */
-void 
+void
 ncm_powspec_clear (NcmPowspec **powspec)
 {
   g_clear_object (powspec);
@@ -261,11 +303,11 @@ ncm_powspec_clear (NcmPowspec **powspec)
  * ncm_powspec_set_zi:
  * @powspec: a #NcmPowspec
  * @zi: initial time $z_i$
- * 
+ *
  * Sets the initial time $z_i$.
  *
  */
-void 
+void
 ncm_powspec_set_zi (NcmPowspec *powspec, const gdouble zi)
 {
   if (powspec->zi != zi)
@@ -279,11 +321,11 @@ ncm_powspec_set_zi (NcmPowspec *powspec, const gdouble zi)
  * ncm_powspec_set_zf:
  * @powspec: a #NcmPowspec
  * @zf: final time $z_f$
- * 
+ *
  * Sets the final time $z_f$.
  *
  */
-void 
+void
 ncm_powspec_set_zf (NcmPowspec *powspec, const gdouble zf)
 {
   if (powspec->zf != zf)
@@ -297,11 +339,11 @@ ncm_powspec_set_zf (NcmPowspec *powspec, const gdouble zf)
  * ncm_powspec_set_kmin:
  * @powspec: a #NcmPowspec
  * @kmin: minimum mode $k_\mathrm{min}$
- * 
+ *
  * Sets the minimum mode value $k_\mathrm{min}$.
  *
  */
-void 
+void
 ncm_powspec_set_kmin (NcmPowspec *powspec, const gdouble kmin)
 {
   if (powspec->kmin != kmin)
@@ -315,11 +357,11 @@ ncm_powspec_set_kmin (NcmPowspec *powspec, const gdouble kmin)
  * ncm_powspec_set_kmax:
  * @powspec: a #NcmPowspec
  * @kmax: maxmimum mode $k_\mathrm{max}$
- * 
+ *
  * Sets the maximum mode value $k_\mathrm{max}$.
  *
  */
-void 
+void
 ncm_powspec_set_kmax (NcmPowspec *powspec, const gdouble kmax)
 {
   if (powspec->kmax != kmax)
@@ -333,11 +375,11 @@ ncm_powspec_set_kmax (NcmPowspec *powspec, const gdouble kmax)
  * ncm_powspec_require_zi:
  * @powspec: a #NcmPowspec
  * @zi: initial time $z_i$
- * 
+ *
  * Requires the initial time to be less or equal to $z_i$.
  *
  */
-void 
+void
 ncm_powspec_require_zi (NcmPowspec *powspec, const gdouble zi)
 {
   if (zi < powspec->zi)
@@ -348,11 +390,11 @@ ncm_powspec_require_zi (NcmPowspec *powspec, const gdouble zi)
  * ncm_powspec_require_zf:
  * @powspec: a #NcmPowspec
  * @zf: final time $z_f$
- * 
+ *
  * Requires the final time to be greater or equal to $z_f$.
  *
  */
-void 
+void
 ncm_powspec_require_zf (NcmPowspec *powspec, const gdouble zf)
 {
   if (zf > powspec->zf)
@@ -363,11 +405,11 @@ ncm_powspec_require_zf (NcmPowspec *powspec, const gdouble zf)
  * ncm_powspec_require_kmin:
  * @powspec: a #NcmPowspec
  * @kmin: minimum mode $k_\mathrm{min}$
- * 
+ *
  * Requires the minimum mode value to be less or equal to $k_\mathrm{min}$.
  *
  */
-void 
+void
 ncm_powspec_require_kmin (NcmPowspec *powspec, const gdouble kmin)
 {
   if (kmin < powspec->kmin)
@@ -378,25 +420,25 @@ ncm_powspec_require_kmin (NcmPowspec *powspec, const gdouble kmin)
  * ncm_powspec_require_kmax:
  * @powspec: a #NcmPowspec
  * @kmax: maxmimum mode $k_\mathrm{max}$
- * 
+ *
  * Sets the maximum mode value $k_\mathrm{max}$.
  *
  */
-void 
+void
 ncm_powspec_require_kmax (NcmPowspec *powspec, const gdouble kmax)
 {
   if (kmax > powspec->kmax)
-    ncm_powspec_set_kmax (powspec, kmax);  
+    ncm_powspec_set_kmax (powspec, kmax);
 }
 
 /**
  * ncm_powspec_get_zi:
  * @powspec: a #NcmPowspec
- * 
+ *
  * Gets the initial value $z_i$.
  *
  */
-gdouble 
+gdouble
 ncm_powspec_get_zi (NcmPowspec *powspec)
 {
   return powspec->zi;
@@ -405,25 +447,24 @@ ncm_powspec_get_zi (NcmPowspec *powspec)
 /**
  * ncm_powspec_get_zf:
  * @powspec: a #NcmPowspec
- * 
+ *
  * Gets the final value $z_f$.
  *
  */
-gdouble 
+gdouble
 ncm_powspec_get_zf (NcmPowspec *powspec)
 {
   return powspec->zf;
 }
 
-
 /**
  * ncm_powspec_get_kmin:
  * @powspec: a #NcmPowspec
- * 
+ *
  * Gets the minimum mode value $k_\mathrm{min}$.
  *
  */
-gdouble 
+gdouble
 ncm_powspec_get_kmin (NcmPowspec *powspec)
 {
   return powspec->kmin;
@@ -432,11 +473,11 @@ ncm_powspec_get_kmin (NcmPowspec *powspec)
 /**
  * ncm_powspec_get_kmax:
  * @powspec: a #NcmPowspec
- * 
+ *
  * Gets the maximum mode value $k_\mathrm{max}$.
  *
  */
-gdouble 
+gdouble
 ncm_powspec_get_kmax (NcmPowspec *powspec)
 {
   return powspec->kmax;
@@ -447,11 +488,11 @@ ncm_powspec_get_kmax (NcmPowspec *powspec)
  * @powspec: a #NcmPowspec
  * @Nz: (out): number of knots in $z$
  * @Nk: (out): number of knots in $k$
- * 
+ *
  * Gets the number of knots used to calculate the power spectrum.
  *
  */
-void 
+void
 ncm_powspec_get_nknots (NcmPowspec *powspec, guint *Nz, guint *Nk)
 {
   NCM_POWSPEC_GET_CLASS (powspec)->get_nknots (powspec, Nz, Nk);
@@ -461,9 +502,9 @@ ncm_powspec_get_nknots (NcmPowspec *powspec, guint *Nz, guint *Nk)
  * ncm_powspec_prepare:
  * @powspec: a #NcmPowspec
  * @model: a #NcmModel
- * 
+ *
  * Prepares the power spectrum @powspec using the model @model.
- * 
+ *
  */
 /**
  * ncm_powspec_prepare_if_needed:
@@ -480,9 +521,9 @@ ncm_powspec_get_nknots (NcmPowspec *powspec, guint *Nz, guint *Nk)
  * @model: a #NcmModel
  * @z: time $z$
  * @k: mode $k$
- * 
+ *
  * Evaluates the power spectrum @powspec at $(z, k)$.
- * 
+ *
  * Returns: $P(z, k)$.
  */
 /**
@@ -492,10 +533,10 @@ ncm_powspec_get_nknots (NcmPowspec *powspec, guint *Nz, guint *Nk)
  * @z: time $z$
  * @k: a #NcmVector
  * @Pk: (out caller-allocates): a #NcmVector
- * 
+ *
  * Evaluates the power spectrum @powspec at $z$ and in the knots
  * contained in @k and puts the result in @Pk.
- * 
+ *
  */
 
 typedef struct _NcmPowspecInt
@@ -510,11 +551,11 @@ static gdouble
 _ncm_powspec_var_tophat_R_integ (gdouble lnk, gpointer user_data)
 {
   NcmPowspecInt *data = (NcmPowspecInt *) user_data;
-  const gdouble k  = exp (lnk);
-  const gdouble x  = k * data->R;
-  const gdouble Pk = ncm_powspec_eval (data->ps, data->model, data->z, k);
-  const gdouble W  = 3.0 * gsl_sf_bessel_j1 (x) / x;
-  const gdouble W2 = W * W;
+  const gdouble k     = exp (lnk);
+  const gdouble x     = k * data->R;
+  const gdouble Pk    = ncm_powspec_eval (data->ps, data->model, data->z, k);
+  const gdouble W     = 3.0 * gsl_sf_bessel_j1 (x) / x;
+  const gdouble W2    = W * W;
   
   return gsl_pow_3 (k) * Pk * W2;
 }
@@ -526,32 +567,40 @@ _ncm_powspec_var_tophat_R_integ (gdouble lnk, gpointer user_data)
  * @reltol: relative tolerance for integration
  * @z: the value of $z$
  * @R: the value of $R$
- * 
- * Computes $\mathrm{Var}^\mathrm{tophat}_R = \int\dots$. FIXME
- * 
+ *
+ * This function computes the value of the linearly extrapolated
+ * rms fluctuations of mass in a sphere of radius $R$ applying a top-hat filter at redshift $z$,
+ * $$\sigma_{R}^{2}(z) = \frac{1}{2\pi^2} \int_{k_{\mathrm{min}}}^{k_\mathrm{max}}  W^{2}_{TH}(kR) \, P(k,z) \, k^2 \, \mathrm{d}k \, .$$
+ * Where, $W_{TH}(t)$ is the top-hat filter in Fourier space,
+ * $$W_{TH}(t) = \frac{3}{t^3} \left( \sin t - t \cos t  \right) = \frac{3}{t} j_{1}(t),$$
+ * and $j_1(t)$ is the first order spherical Bessel function of the first kind.
+ * This function is recommended for a small set of $z$ and $R$ values.
+ * For a wide range of values it is best to apply #NcmPowspecFilter, instead.
+ *
+ * Returns: $\sigma_{R}^{2}(z)$.
  */
-gdouble 
+gdouble
 ncm_powspec_var_tophat_R (NcmPowspec *ps, NcmModel *model, const gdouble reltol, const gdouble z, const gdouble R)
 {
   gsl_integration_workspace **w = ncm_integral_get_workspace ();
-  NcmPowspecInt data            = {z, R, ps, model};
-  const gdouble kmin            = ncm_powspec_get_kmin (ps);
-  const gdouble kmax            = ncm_powspec_get_kmax (ps);  
-  const gdouble lnkmin          = log (kmin);
-  const gdouble lnkmax          = log (kmax);
-  const gdouble one_2pi2        = 1.0 / ncm_c_2_pi_2 ();
+  NcmPowspecInt data = {z, R, ps, model};
+  const gdouble kmin = ncm_powspec_get_kmin (ps);
+  const gdouble kmax = ncm_powspec_get_kmax (ps);
+  const gdouble lnkmin = log (kmin);
+  const gdouble lnkmax = log (kmax);
+  const gdouble one_2pi2 = 1.0 / ncm_c_2_pi_2 ();
   gdouble error, sigma2_2pi2;
   gsl_function F;
   
   ncm_powspec_prepare_if_needed (ps, model);
-
+  
   F.function = &_ncm_powspec_var_tophat_R_integ;
   F.params   = &data;
   
   gsl_integration_qag (&F, lnkmin, lnkmax, 0.0, reltol, NCM_INTEGRAL_PARTITION, 6, *w, &sigma2_2pi2, &error);
-
-  ncm_memory_pool_return (w);  
-
+  
+  ncm_memory_pool_return (w);
+  
   return sigma2_2pi2 * one_2pi2;
 }
 
@@ -562,11 +611,12 @@ ncm_powspec_var_tophat_R (NcmPowspec *ps, NcmModel *model, const gdouble reltol,
  * @reltol: relative tolerance for integration
  * @z: the value of $z$
  * @R: the value of $R$
- * 
- * Computes $\sigma^\mathrm{tophat}_R = \sqrt{\int\dots}$. FIXME
- * 
+ *
+ * Computes $\sigma_R(z) = \sqrt{\sigma_{R}^{2}(z)}$. See ncm_powspec_var_tophat_R().
+ *
+ * Returns: $\sigma_R(z)$.
  */
-gdouble 
+gdouble
 ncm_powspec_sigma_tophat_R (NcmPowspec *ps, NcmModel *model, const gdouble reltol, const gdouble z, const gdouble R)
 {
   return sqrt (ncm_powspec_var_tophat_R (ps, model, reltol, z, R));
@@ -576,11 +626,11 @@ static gdouble
 _ncm_powspec_var_corr3D_integ (gdouble lnk, gpointer user_data)
 {
   NcmPowspecInt *data = (NcmPowspecInt *) user_data;
-  const gdouble k  = exp (lnk);
-  const gdouble x  = k * data->R;
-  const gdouble Pk = ncm_powspec_eval (data->ps, data->model, data->z, k);
-  const gdouble W  = gsl_sf_bessel_j0 (x);
-
+  const gdouble k     = exp (lnk);
+  const gdouble x     = k * data->R;
+  const gdouble Pk    = ncm_powspec_eval (data->ps, data->model, data->z, k);
+  const gdouble W     = gsl_sf_bessel_j0 (x);
+  
   return gsl_pow_3 (k) * Pk * W;
 }
 
@@ -591,31 +641,37 @@ _ncm_powspec_var_corr3D_integ (gdouble lnk, gpointer user_data)
  * @reltol: relative tolerance for integration
  * @z: the value of $z$
  * @r: the value of $r$
- * 
- * Computes $\xi(r) = \int\dots$. FIXME
- * 
+ *
+ * Computes the spatial correlation function in configuration space at redshift $z$ and position $r$,
+ * $$\xi(r,z) = \frac{1}{2\pi^2} \int_{k_{\mathrm{min}}}^{k_\mathrm{max}} P(k,z) \, j_{0}(kr) \, k^2 \, \mathrm{d}k \, ,$$
+ * where, $j_0(t)$ is the zero order spherical Bessel function of the first kind.
+ * This function is recommended for a small set of $r$ and $z$ values.
+ * For a wide range of values it is best to apply #NcmPowspecCorr3d, instead.
+ *
+ * Returns: $\xi(r,z)$.
  */
-gdouble 
+gdouble
 ncm_powspec_corr3d (NcmPowspec *ps, NcmModel *model, const gdouble reltol, const gdouble z, const gdouble r)
 {
   gsl_integration_workspace **w = ncm_integral_get_workspace ();
-  NcmPowspecInt data            = {z, r, ps, model};
-  const gdouble kmin            = ncm_powspec_get_kmin (ps);
-  const gdouble kmax            = ncm_powspec_get_kmax (ps);  
-  const gdouble lnkmin          = log (kmin);
-  const gdouble lnkmax          = log (kmax);
-  const gdouble one_2pi2        = 1.0 / ncm_c_2_pi_2 ();
+  NcmPowspecInt data = {z, r, ps, model};
+  const gdouble kmin = ncm_powspec_get_kmin (ps);
+  const gdouble kmax = ncm_powspec_get_kmax (ps);
+  const gdouble lnkmin = log (kmin);
+  const gdouble lnkmax = log (kmax);
+  const gdouble one_2pi2 = 1.0 / ncm_c_2_pi_2 ();
   gdouble error, xi_2pi2;
   gsl_function F;
   
   ncm_powspec_prepare_if_needed (ps, model);
-
+  
   F.function = &_ncm_powspec_var_corr3D_integ;
   F.params   = &data;
   
   gsl_integration_qag (&F, lnkmin, lnkmax, 0.0, reltol, NCM_INTEGRAL_PARTITION, 6, *w, &xi_2pi2, &error);
-
-  ncm_memory_pool_return (w);  
-
+  
+  ncm_memory_pool_return (w);
+  
   return xi_2pi2 * one_2pi2;
 }
+
